git: 9a0a6ca38c78 - main - www/qt6-webengine: Update to 6.5.0
- Go to: [ bottom of page ] [ top of archives ] [ this month ]
Date: Wed, 26 Jul 2023 04:29:44 UTC
The branch main has been updated by lbartoletti:
URL: https://cgit.FreeBSD.org/ports/commit/?id=9a0a6ca38c78e60b3afc10152daad948a1f001c7
commit 9a0a6ca38c78e60b3afc10152daad948a1f001c7
Author: Kai Knoblich <kai@FreeBSD.org>
AuthorDate: 2023-04-23 16:35:04 +0000
Commit: Loïc Bartoletti <lbartoletti@FreeBSD.org>
CommitDate: 2023-07-26 04:28:56 +0000
www/qt6-webengine: Update to 6.5.0
Under the hood runs Chromium 108.0.5359.181 with security patches up to
Chromium 110.0.5481.104. Most of the patches were taken of from
Chromium 108.0.5359.124 (7ae5e0e6d6ee).
Build tests so far:
- 14.0-CURRENT@ amd64@df2fbbfa71
- 13.2-RELEASE amd64 ALSA
- 13.1-RELEASE amd64 ALSA
- 12.4-RELEASE amd64 + i386 (ALSA/PULSE/SNDIO)
Runtime tests with 12.4-RELEASE so far without issues.
PR: 272422
Exp-run by: antoine
---
www/qt6-webengine/Makefile | 12 +---
www/qt6-webengine/distinfo | 6 +-
.../files/patch-src_3rdparty_chromium_BUILD.gn | 33 +++++----
.../patch-src_3rdparty_chromium_base_BUILD.gn | 81 ++++++++++-----------
...tion__allocator_address__space__randomization.h | 4 +-
...llocator_partition__allocator_page__allocator.h | 8 +--
...rtition__allocator_page__allocator__constants.h | 23 ++++--
...__allocator_page__allocator__internals__posix.h | 4 +-
...rtition__allocator_partition__address__space.cc | 6 +-
...ocator_partition__allocator_partition__alloc.cc | 17 -----
...tor_partition__alloc__base_rand__util__posix.cc | 13 ++++
...e_threading_platform__thread__internal__posix.h | 11 +++
...lloc__base_threading_platform__thread__posix.cc | 11 +++
...partition__allocator_partition__alloc__config.h | 10 +--
...tition__allocator_partition__alloc__constants.h | 15 +++-
...artition__allocator_partition__alloc__forward.h | 16 +++++
...llocator_partition__allocator_partition__page.h | 17 +----
...locator_partition__allocator_partition__root.cc | 12 ++--
...locator_partition__allocator_spinning__mutex.cc | 8 +--
...llocator_partition__allocator_spinning__mutex.h | 20 ------
...ch-src_3rdparty_chromium_base_base__switches.cc | 8 +--
...tch-src_3rdparty_chromium_base_base__switches.h | 6 +-
.../files/patch-src_3rdparty_chromium_base_cpu.h | 4 +-
...src_3rdparty_chromium_base_debug_elf__reader.cc | 10 +--
...arty_chromium_base_debug_stack__trace__posix.cc | 12 ++--
...dparty_chromium_base_files_dir__reader__linux.h | 39 ++++++++++
...dparty_chromium_base_files_dir__reader__posix.h | 20 ++++++
...chromium_base_files_file__path__watcher__bsd.cc | 4 +-
...mium_base_files_file__path__watcher__freebsd.cc | 64 -----------------
...dparty_chromium_base_files_file__util__posix.cc | 4 +-
...ch-src_3rdparty_chromium_base_i18n_icu__util.cc | 18 ++---
...patch-src_3rdparty_chromium_base_linux__util.cc | 4 +-
...rty_chromium_base_memory_discardable__memory.cc | 18 ++---
..._base_memory_platform__shared__memory__region.h | 6 +-
...omium_base_message__loop_message__pump__glib.cc | 6 +-
...rty_chromium_base_posix_unix__domain__socket.cc | 10 +--
...tch-src_3rdparty_chromium_base_process_launch.h | 4 +-
...ch-src_3rdparty_chromium_base_process_memory.cc | 13 +---
...party_chromium_base_process_process__metrics.cc | 25 ++++---
...dparty_chromium_base_process_process__metrics.h | 34 +++++----
...omium_base_process_process__metrics__freebsd.cc | 28 +++++---
...omium_base_process_process__metrics__openbsd.cc | 27 +++----
...hromium_base_process_process__metrics__posix.cc | 4 +-
...rdparty_chromium_base_process_process__posix.cc | 10 +--
...rdparty_chromium_base_profiler_module__cache.cc | 11 +++
...e_profiler_sampling__profiler__thread__token.cc | 20 ++++++
...se_profiler_sampling__profiler__thread__token.h | 20 ++++++
...um_base_profiler_stack__base__address__posix.cc | 44 ++++++++++++
...romium_base_profiler_thread__delegate__posix.cc | 20 ++++++
.../patch-src_3rdparty_chromium_base_rand__util.h | 6 +-
...src_3rdparty_chromium_base_rand__util__posix.cc | 44 +++++++-----
...arty_chromium_base_synchronization_lock__impl.h | 6 +-
...-src_3rdparty_chromium_base_system_sys__info.cc | 20 +++---
...h-src_3rdparty_chromium_base_system_sys__info.h | 12 ++--
...arty_chromium_base_system_sys__info__freebsd.cc | 18 ++---
...arty_chromium_base_system_sys__info__openbsd.cc | 12 ++--
...dparty_chromium_base_system_sys__info__posix.cc | 38 ++++------
...rty_chromium_base_third__party_libevent_event.h | 14 ----
...romium_base_third__party_symbolize_symbolize.cc | 11 ---
...arty_chromium_base_threading_platform__thread.h | 6 +-
...omium_base_threading_platform__thread__linux.cc | 38 +++++-----
...omium_base_threading_platform__thread__posix.cc | 22 +++---
..._base_threading_thread__task__runner__handle.cc | 26 -------
.../patch-src_3rdparty_chromium_base_time_time.cc | 11 ---
...ium_base_trace__event_malloc__dump__provider.cc | 13 ++--
...mium_base_trace__event_process__memory__dump.cc | 12 ++--
...tch-src_3rdparty_chromium_build_config_BUILD.gn | 4 +-
...rdparty_chromium_build_config_compiler_BUILD.gn | 47 +++++++-----
...arty_chromium_build_config_compiler_pgo_pgo.gni | 11 ---
...ch-src_3rdparty_chromium_build_config_ozone.gni | 4 +-
...tch-src_3rdparty_chromium_build_config_rust.gni | 4 +-
...c_3rdparty_chromium_build_linux_libpci_BUILD.gn | 53 --------------
...3rdparty_chromium_build_linux_strip__binary.gni | 15 ----
...rdparty_chromium_build_linux_unbundle_libxml.gn | 10 ---
...mium_build_linux_unbundle_replace__gn__files.py | 6 +-
...rty_chromium_build_toolchain_gcc__toolchain.gni | 15 +++-
...wser_media_webrtc_webrtc__logging__controller.h | 6 +-
...i_webui_chrome__web__ui__controller__factory.cc | 20 +++---
...chromium_chrome_common_webui__url__constants.cc | 12 ++--
..._chromium_chrome_common_webui__url__constants.h | 8 +--
...omium_components_crash_content_browser_BUILD.gn | 29 --------
...rty_chromium_components_crash_core_app_BUILD.gn | 23 ++----
...h_core_browser_crash__upload__list__crashpad.cc | 14 +++-
..._chromium_components_crash_core_common_BUILD.gn | 11 +--
..._components_os__crypt_libsecret__util__linux.cc | 4 +-
...party_chromium_components_os__crypt_os__crypt.h | 57 ++++++++++-----
..._ai_sandbox_screen__ai__sandbox__hook__linux.cc | 8 +--
..._3rdparty_chromium_content_app_content__main.cc | 4 +-
...mium_content_app_content__main__runner__impl.cc | 43 ++++++-----
...-src_3rdparty_chromium_content_browser_BUILD.gn | 6 +-
..._browser_browser__child__process__host__impl.cc | 4 +-
...chromium_content_browser_browser__main__loop.cc | 17 ++---
...wser_child__process__launcher__helper__linux.cc | 28 ++++----
..._compositor_viz__process__transport__factory.cc | 4 +-
...content_browser_compute__pressure_cpu__probe.cc | 10 ---
...ent_browser_download_download__manager__impl.cc | 8 +--
...omium_content_browser_gpu_gpu__process__host.cc | 17 ++---
...ser_media_frameless__media__interface__proxy.cc | 10 +--
...wser_media_frameless__media__interface__proxy.h | 20 ++++++
...ontent_browser_media_media__interface__proxy.cc | 8 +--
...owser_renderer__host_render__message__filter.cc | 16 ++---
...rowser_renderer__host_render__message__filter.h | 11 ++-
...r_renderer__host_render__process__host__impl.cc | 28 ++++++--
...er_renderer__host_render__process__host__impl.h | 31 +++++++-
...wser_renderer__host_render__view__host__impl.cc | 4 +-
...derer__host_render__widget__host__view__aura.cc | 32 ++++-----
...nderer__host_render__widget__host__view__aura.h | 4 +-
...m_content_browser_utility__sandbox__delegate.cc | 26 ++-----
...wser_web__contents_web__contents__view__aura.cc | 8 +--
...browser_webui_web__ui__main__frame__observer.cc | 10 +--
..._browser_webui_web__ui__main__frame__observer.h | 6 +-
...owser_zygote__host_zygote__host__impl__linux.cc | 27 ++++---
...rowser_zygote__host_zygote__host__impl__linux.h | 16 +++--
...h-src_3rdparty_chromium_content_common_BUILD.gn | 4 +-
...3rdparty_chromium_content_common_user__agent.cc | 15 +++-
...ontent_common_zygote_sandbox__support__linux.cc | 14 ----
...-src_3rdparty_chromium_content_gpu_gpu__main.cc | 6 +-
...romium_content_gpu_gpu__sandbox__hook__linux.cc | 18 ++---
...nt_ppapi__plugin_ppapi__blink__platform__impl.h | 6 +-
...um_content_ppapi__plugin_ppapi__plugin__main.cc | 4 +-
..._content_public_browser_render__process__host.h | 20 ++++++
...blic_browser_zygote__host_zygote__host__linux.h | 10 +--
...t_public_common_common__param__traits__macros.h | 4 +-
...mium_content_public_common_content__features.cc | 40 +++++------
...omium_content_public_common_content__features.h | 12 ++--
...mium_content_public_common_content__switches.cc | 6 +-
...omium_content_public_common_content__switches.h | 6 +-
...content_renderer_media_render__media__client.cc | 12 ++--
...omium_content_renderer_render__process__impl.cc | 12 ++--
...romium_content_renderer_render__thread__impl.cc | 25 +++----
...ent_renderer_renderer__blink__platform__impl.cc | 21 +++---
...tent_renderer_renderer__blink__platform__impl.h | 19 +++--
...ch-src_3rdparty_chromium_content_shell_BUILD.gn | 4 +-
...mium_content_shell_app_shell__main__delegate.cc | 4 +-
...hell_utility_shell__content__utility__client.cc | 6 +-
...tch-src_3rdparty_chromium_content_test_BUILD.gn | 6 +-
...c_3rdparty_chromium_content_utility_services.cc | 33 ++++++++-
...party_chromium_content_utility_utility__main.cc | 19 +++--
...dparty_chromium_content_zygote_zygote__linux.cc | 6 +-
..._chromium_content_zygote_zygote__main__linux.cc | 12 ++--
...sions_browser_api_messaging_message__service.cc | 20 ++++++
...ivate_networking__private__delegate__factory.cc | 20 ++++++
..._browser__context__keyed__service__factories.cc | 11 +++
...chromium_extensions_browser_extension__prefs.cc | 11 +++
...arty_chromium_extensions_browser_pref__names.cc | 11 +++
...party_chromium_extensions_browser_pref__names.h | 11 +++
...tensions_common_api___permission__features.json | 29 ++++++++
...rty_chromium_extensions_common_api_runtime.json | 12 ++++
..._3rdparty_chromium_extensions_common_command.cc | 11 +++
..._chromium_extensions_common_features_feature.cc | 11 +++
...ensions_renderer_bindings_api__binding__util.cc | 11 +++
..._extensions_renderer_bindings_argument__spec.cc | 11 +++
...m_extensions_shell_app_shell__main__delegate.cc | 20 ++++++
...er_api_runtime_shell__runtime__api__delegate.cc | 11 +++
...ns_shell_browser_shell__browser__main__parts.cc | 11 +++
...shell_browser_shell__extensions__api__client.cc | 11 +++
..._shell_browser_shell__extensions__api__client.h | 20 ++++++
...__buffer_common_gpu__memory__buffer__support.cc | 6 +-
..._buffer_service_external__vk__image__backing.cc | 20 ------
...mmand__buffer_service_shared__image__factory.cc | 29 --------
...mage_angle__vulkan__image__backing__factory.cc} | 6 +-
...e_shared__image_external__vk__image__backing.cc | 20 ++++++
...e_shared__image_gl__texture__image__backing.cc} | 8 +--
..._image_gl__texture__image__backing__factory.cc} | 6 +-
...__image_wrapped__sk__image__backing__factory.cc | 11 +++
...ommand__buffer_service_webgpu__decoder__impl.cc | 10 +--
...party_chromium_gpu_config_gpu__control__list.cc | 6 +-
...rty_chromium_gpu_config_gpu__finch__features.cc | 21 ++++++
..._3rdparty_chromium_gpu_ipc_service_gpu__init.cc | 34 ++++++---
...ty_chromium_gpu_vulkan_vulkan__device__queue.cc | 4 +-
...rty_chromium_gpu_vulkan_vulkan__device__queue.h | 4 +-
...rc_3rdparty_chromium_gpu_vulkan_vulkan__util.cc | 11 +++
.../patch-src_3rdparty_chromium_media_BUILD.gn | 4 +-
...atch-src_3rdparty_chromium_media_audio_BUILD.gn | 4 +-
...rdparty_chromium_media_audio_audio__features.cc | 11 ---
...ty_chromium_media_audio_audio__input__device.cc | 4 +-
...mium_media_audio_sndio_audio__manager__sndio.cc | 12 ++--
..._3rdparty_chromium_media_base_audio__latency.cc | 4 +-
...3rdparty_chromium_media_base_media__switches.cc | 46 +++++++-----
..._3rdparty_chromium_media_base_media__switches.h | 27 ++++---
...rdparty_chromium_media_base_supported__types.cc | 16 ++---
...rc_3rdparty_chromium_media_base_vector__math.cc | 11 ---
...rc_3rdparty_chromium_media_base_video__frame.cc | 16 ++---
...src_3rdparty_chromium_media_base_video__frame.h | 12 ++--
...m_media_capture_video_linux_fake__v4l2__impl.cc | 4 +-
..._capture_video_linux_v4l2__capture__delegate.cc | 8 +--
...a_capture_video_linux_v4l2__capture__delegate.h | 4 +-
...ure_video_video__capture__buffer__pool__impl.cc | 11 ---
...capture_video_video__capture__device__client.cc | 4 +-
..._media_gpu_chromeos_video__decoder__pipeline.cc | 12 ++--
...gpu_gpu__video__encode__accelerator__factory.cc | 4 +-
...dware__video__decoding__sandbox__hook__linux.cc | 4 +-
...romium_media_gpu_vaapi_vaapi__video__decoder.cc | 4 +-
...arty_chromium_media_gpu_vaapi_vaapi__wrapper.cc | 11 ---
...-src_3rdparty_chromium_media_media__options.gni | 19 ++---
...stable__video__decoder__types__mojom__traits.cc | 6 +-
..._stable__video__decoder__types__mojom__traits.h | 4 +-
...media_mojo_mojom_video__frame__mojom__traits.cc | 4 +-
...ideo_gpu__memory__buffer__video__frame__pool.cc | 22 +++++-
...ia_video_video__encode__accelerator__adapter.cc | 16 ++---
...eo_video__encode__accelerator__adapter__test.cc | 14 ++--
...party_chromium_media_webrtc_audio__processor.cc | 4 +-
...party_chromium_media_webrtc_webrtc__features.cc | 11 ++-
.../files/patch-src_3rdparty_chromium_net_BUILD.gn | 42 +++++------
..._chromium_net_base_network__change__notifier.cc | 12 ++--
...um_net_base_network__change__notifier__posix.cc | 6 +-
...rty_chromium_net_base_sockaddr__util__posix.cc} | 7 +-
...rc_3rdparty_chromium_net_cert_cert__verifier.cc | 16 ++---
...rdparty_chromium_net_cert_cert__verify__proc.cc | 4 +-
...3rdparty_chromium_net_cert_cert__verify__proc.h | 4 +-
...romium_net_disk__cache_blockfile_disk__format.h | 4 +-
...net_disk__cache_simple_simple__file__tracker.cc | 4 +-
.../patch-src_3rdparty_chromium_net_dns_BUILD.gn | 8 +--
...chromium_net_dns_dns__config__service__posix.cc | 6 +-
...h-src_3rdparty_chromium_net_dns_dns__reloader.h | 10 ++-
...rty_chromium_net_dns_host__resolver__manager.cc | 11 ---
...dparty_chromium_net_dns_host__resolver__proc.cc | 17 ++---
...hromium_net_dns_host__resolver__system__task.cc | 22 ++++++
...h-src_3rdparty_chromium_net_dns_public_BUILD.gn | 4 +-
..._chromium_net_http_http__auth__gssapi__posix.cc | 4 +-
...y_chromium_net_http_http__auth__gssapi__posix.h | 4 +-
...et_proxy__resolution_proxy__config__service.cc} | 22 +++---
...xy__resolution_proxy__config__service__linux.cc | 10 +--
...c_3rdparty_chromium_net_socket_socket__posix.cc | 4 +-
...party_chromium_net_socket_tcp__socket__posix.cc | 16 ++---
...party_chromium_net_socket_udp__socket__posix.cc | 8 +--
...party_chromium_net_third__party_quiche_BUILD.gn | 38 +++-------
...verify__tool_cert__verify__comparision__tool.cc | 6 +-
..._tools_cert__verify__tool_cert__verify__tool.cc | 8 +--
...um_net_tools_quic_quic__http__proxy__backend.cc | 11 ---
...ffic__annotation_network__traffic__annotation.h | 6 +-
...party_chromium_net_url__request_url__fetcher.cc | 11 ---
...dparty_chromium_net_url__request_url__fetcher.h | 11 ---
...omium_net_url__request_url__request__context.cc | 4 +-
...romium_net_url__request_url__request__context.h | 4 +-
..._url__request_url__request__context__builder.cc | 6 +-
...nting_mojom_printing__context__mojom__traits.cc | 6 +-
...inting_mojom_printing__context__mojom__traits.h | 4 +-
...hromium_printing_print__settings__conversion.cc | 4 +-
...y_chromium_printing_printing__context__linux.cc | 38 ++++++++++
...rdparty_chromium_printing_printing__features.cc | 11 ---
.../patch-src_3rdparty_chromium_sandbox_BUILD.gn | 4 +-
...ium_sandbox_linux_services_libc__interceptor.cc | 6 +-
...h-src_3rdparty_chromium_sandbox_policy_BUILD.gn | 14 ++--
...rc_3rdparty_chromium_sandbox_policy_features.cc | 12 ++--
...omium_sandbox_policy_freebsd_sandbox__freebsd.h | 4 +-
...omium_sandbox_policy_openbsd_sandbox__openbsd.h | 4 +-
...src_3rdparty_chromium_sandbox_policy_sandbox.cc | 6 +-
...dparty_chromium_sandbox_policy_sandbox__type.cc | 51 +++----------
...rc_3rdparty_chromium_sandbox_policy_switches.cc | 6 +-
...src_3rdparty_chromium_sandbox_policy_switches.h | 6 +-
...ices_cert__verifier_cert__verifier__creation.cc | 42 ++++++-----
..._instrumentation_queued__request__dispatcher.cc | 16 ++---
...mium_third__party_abseil-cpp_absl_base_config.h | 6 +-
..._party_abseil-cpp_absl_base_internal_sysinfo.cc | 4 +-
...l-cpp_absl_debugging_internal_elf__mem__image.h | 13 ++--
...sl_time_internal_cctz_src_time__zone__format.cc | 4 +-
...c_3rdparty_chromium_third__party_angle_BUILD.gn | 26 +++++--
...party_angle_src_common_system__utils__posix.cpp | 12 ----
...m_third__party_angle_src_common_vulkan_BUILD.gn | 11 +++
...ium_third__party_angle_src_libANGLE_Display.cpp | 16 ++---
...third__party_angle_src_libANGLE_formatutils.cpp | 4 +-
...rty_angle_src_libANGLE_renderer_driver__utils.h | 4 +-
...e_src_libANGLE_renderer_vulkan_DisplayVk__api.h | 6 +-
...ird__party_angle_src_third__party_volk_BUILD.gn | 11 +++
...party_chromium_third__party_angle_util_BUILD.gn | 4 +-
...link_common_privacy__budget_active__sampling.cc | 11 +++
...m_third__party_blink_public_platform_platform.h | 11 +++
...blink_renderer_controller_blink__initializer.cc | 16 ++---
...rer_controller_memory__usage__monitor__posix.cc | 4 +-
...erer_core_execution__context_navigator__base.cc | 11 +++
...blink_renderer_core_exported_web__view__impl.cc | 6 +-
...y_blink_renderer_core_frame_web__frame__test.cc | 18 ++---
...erer_core_inspector_inspector__memory__agent.cc | 4 +-
...arty_blink_renderer_core_layout_layout__view.cc | 6 +-
...party_blink_renderer_core_paint_paint__layer.cc | 4 +-
..._renderer_core_scroll_scrollbar__theme__aura.cc | 6 +-
...r_modules_media_audio_audio__device__factory.cc | 6 +-
..._audio_audio__renderer__mixer__manager__test.cc | 4 +-
...peerconnection_webrtc__audio__renderer__test.cc | 4 +-
...odules_webaudio_audio__worklet__thread__test.cc | 8 +--
...odules_webgl_webgl__rendering__context__base.cc | 4 +-
...modules_webgl_webgl__webcodecs__video__frame.cc | 4 +-
...m_third__party_blink_renderer_platform_BUILD.gn | 4 +-
...ty_blink_renderer_platform_fonts_font__cache.cc | 8 +--
...rty_blink_renderer_platform_fonts_font__cache.h | 10 +--
...nk_renderer_platform_fonts_font__description.cc | 4 +-
...renderer_platform_fonts_font__platform__data.cc | 20 ++++++
...rer_platform_graphics_begin__frame__provider.cc | 11 +--
...er_platform_graphics_video__frame__submitter.cc | 4 +-
..._peerconnection_rtc__video__encoder__factory.cc | 17 +++++
...derer_platform_runtime__enabled__features.json5 | 34 ++++-----
...nk_renderer_platform_scheduler_common_thread.cc | 11 ++-
...widget_compositing_categorized__worker__pool.cc | 11 +++
...arty_blink_renderer_platform_wtf_math__extras.h | 15 +++-
...mium_third__party_boringssl_BUILD.generated.gni | 9 +--
...boringssl_src_crypto_fipsmodule_rand_internal.h | 4 +-
...ird__party_boringssl_src_crypto_refcount__c11.c | 8 +--
...ird__party_boringssl_src_include_openssl_base.h | 4 +-
...ashpad_minidump_minidump__misc__info__writer.cc | 4 +-
...__party_crashpad_crashpad_util_posix_signals.cc | 4 +-
...arty_dawn_generator_dawn__version__generator.py | 22 ------
..._party_dawn_include_dawn_native_VulkanBackend.h | 12 ++--
...um_third__party_dawn_src_dawn_common_Platform.h | 18 ++---
...party_dawn_src_dawn_native_vulkan_BackendVk.cpp | 12 ++--
..._chromium_third__party_harfbuzz-ng_harfbuzz.gni | 22 ------
...rc_3rdparty_chromium_third__party_nasm_BUILD.gn | 16 +++++
...hromium_third__party_nasm_config_config-linux.h | 84 +++++++++++++++++++++-
...hird__party_pdfium_core_fxcrt_cfx__datetime.cpp | 11 ---
...ird__party_pdfium_core_fxge_cfx__fontmapper.cpp | 4 +-
...arty_pdfium_core_fxge_linux_fx__linux__impl.cpp | 4 +-
..._third__party_pdfium_fxjs_fx__date__helpers.cpp | 6 +-
..._perfetto_include_perfetto_base_thread__utils.h | 6 +-
...erfetto_protos_perfetto_trace_ftrace_v4l2.proto | 56 +++++++++++++++
..._third__party_perfetto_src_base_unix__socket.cc | 4 +-
...etto_src_tracing_core_tracing__service__impl.cc | 4 +-
...rty_protobuf_src_google_protobuf_arenastring.cc | 12 ++++
...uf_src_google_protobuf_stubs_platform__macros.h | 11 +++
...party_chromium_third__party_tflite_features.gni | 11 +++
...arty_chromium_third__party_wayland_features.gni | 31 ++++----
..._3rdparty_chromium_third__party_webrtc_BUILD.gn | 4 +-
...rd__party_webrtc_modules_audio__device_BUILD.gn | 4 +-
...chromium_third__party_webrtc_rtc__base_BUILD.gn | 4 +-
...romium_third__party_webrtc_rtc__base_network.cc | 6 +-
...ty_webrtc_rtc__base_physical__socket__server.cc | 16 ++---
...rty_webrtc_rtc__base_physical__socket__server.h | 6 +-
...dparty_chromium_tools_generate__stubs_rules.gni | 10 +++
...son__schema__compiler_cpp__bundle__generator.py | 11 +++
...ols_json__schema__compiler_feature__compiler.py | 11 +++
...ls_memory_partition__allocator_inspect__utils.h | 11 +++
...um_tools_perf_chrome__telemetry__build_BUILD.gn | 20 ++++++
...romium_tools_protoc__wrapper_protoc__wrapper.py | 24 +++++++
...mium_tools_variations_fieldtrial__to__struct.py | 11 +++
...-src_3rdparty_chromium_ui_aura_screen__ozone.cc | 10 +--
...h-src_3rdparty_chromium_ui_aura_screen__ozone.h | 21 ++++--
...omium_ui_base_ime_dummy__text__input__client.cc | 4 +-
...romium_ui_base_ime_dummy__text__input__client.h | 4 +-
...romium_ui_base_ime_fake__text__input__client.cc | 4 +-
...hromium_ui_base_ime_fake__text__input__client.h | 4 +-
..._ui_base_ime_init_input__method__initializer.cc | 38 ----------
...linux_linux__input__method__context__factory.cc | 20 ++++++
...arty_chromium_ui_base_ime_text__input__client.h | 4 +-
...y_chromium_ui_base_resource_resource__bundle.cc | 4 +-
...3rdparty_chromium_ui_base_ui__base__features.cc | 26 +++----
...src_3rdparty_chromium_ui_base_ui__base__types.h | 11 +++
...rdparty_chromium_ui_base_webui_web__ui__util.cc | 4 +-
...arty_chromium_ui_base_x_x11__cursor__factory.cc | 11 +++
...party_chromium_ui_base_x_x11__cursor__factory.h | 20 ++++++
...party_chromium_ui_base_x_x11__cursor__loader.cc | 31 +++++++-
...atch-src_3rdparty_chromium_ui_color_color__id.h | 8 +--
...rty_chromium_ui_color_color__provider__utils.cc | 11 +++
...arty_chromium_ui_color_native__color__mixers.cc | 17 -----
...-src_3rdparty_chromium_ui_color_system__theme.h | 11 +++
...c_3rdparty_chromium_ui_compositor_compositor.cc | 4 +-
...rc_3rdparty_chromium_ui_compositor_compositor.h | 4 +-
...atch-src_3rdparty_chromium_ui_display_screen.cc | 8 +--
...patch-src_3rdparty_chromium_ui_display_screen.h | 15 +---
.../patch-src_3rdparty_chromium_ui_events_event.cc | 6 +-
..._3rdparty_chromium_ui_events_event__switches.cc | 8 +--
...c_3rdparty_chromium_ui_events_event__switches.h | 6 +-
.../patch-src_3rdparty_chromium_ui_gfx_BUILD.gn | 4 +-
...dparty_chromium_ui_gfx_font__fallback__linux.cc | 4 +-
..._chromium_ui_gfx_font__render__params__linux.cc | 20 ++++++
..._3rdparty_chromium_ui_gfx_gpu__memory__buffer.h | 10 +--
...hromium_ui_gfx_ipc_gfx__param__traits__macros.h | 44 ------------
...um_ui_gfx_mojom_buffer__types__mojom__traits.cc | 4 +-
...x_mojom_native__handle__types__mojom__traits.cc | 6 +-
...fx_mojom_native__handle__types__mojom__traits.h | 11 ++-
...party_chromium_ui_gfx_native__pixmap__handle.cc | 28 ++++----
...dparty_chromium_ui_gfx_native__pixmap__handle.h | 12 ++--
...rdparty_chromium_ui_gfx_platform__font__skia.cc | 20 ++++++
...ty_chromium_ui_gfx_render__text__api__fuzzer.cc | 41 +++++------
...rdparty_chromium_ui_gfx_render__text__fuzzer.cc | 20 ++++++
.../patch-src_3rdparty_chromium_ui_gl_BUILD.gn | 10 +--
...c_3rdparty_chromium_ui_gl_generate__bindings.py | 4 +-
...atch-src_3rdparty_chromium_ui_gl_gl__context.cc | 4 +-
...tch-src_3rdparty_chromium_ui_gl_gl__features.cc | 20 +++---
...hromium_ui_gl_gl__image__glx__native__pixmap.cc | 8 +--
...c_3rdparty_chromium_ui_gl_gl__implementation.cc | 11 +++
...tch-src_3rdparty_chromium_ui_gl_gl__switches.cc | 20 ++++++
..._chromium_ui_gtk_printing_print__dialog__gtk.cc | 4 +-
...i_message__center_views_message__popup__view.cc | 4 +-
..._3rdparty_chromium_ui_ozone_common_egl__util.cc | 4 +-
...platform_headless_headless__surface__factory.cc | 20 +++---
..._platform_headless_headless__surface__factory.h | 11 ---
..._platform_headless_ozone__platform__headless.cc | 10 +--
...rm_headless_vulkan__implementation__headless.cc | 11 +++
...m_ui_ozone_platform_x11_ozone__platform__x11.cc | 4 +-
...arty_chromium_ui_ozone_public_ozone__platform.h | 4 +-
...i_ozone_test_mock__platform__window__delegate.h | 11 +++
..._platform__window_platform__window__delegate.cc | 11 +++
...i_platform__window_platform__window__delegate.h | 11 +++
...rm__window_platform__window__init__properties.h | 10 +--
...y_chromium_ui_strings_app__locale__settings.grd | 6 +-
...ings_translations_app__locale__settings__bn.xtb | 8 +--
...ings_translations_app__locale__settings__ja.xtb | 8 +--
...ings_translations_app__locale__settings__ko.xtb | 8 +--
...ings_translations_app__locale__settings__ml.xtb | 8 +--
...ings_translations_app__locale__settings__th.xtb | 8 +--
...s_translations_app__locale__settings__zh-CN.xtb | 8 +--
...s_translations_app__locale__settings__zh-TW.xtb | 10 +--
..._chromium_ui_views_controls_prefix__selector.cc | 4 +-
...y_chromium_ui_views_controls_prefix__selector.h | 4 +-
...romium_ui_views_controls_textfield_textfield.cc | 48 ++++++-------
...hromium_ui_views_controls_textfield_textfield.h | 13 +++-
...party_chromium_ui_views_corewm_tooltip__aura.cc | 4 +-
...y_chromium_ui_views_examples_widget__example.cc | 4 +-
...party_chromium_ui_views_focus_focus__manager.cc | 6 +-
...dparty_chromium_ui_views_linux__ui_linux__ui.cc | 11 ---
...rdparty_chromium_ui_views_linux__ui_linux__ui.h | 20 ------
...arty_chromium_ui_views_style_platform__style.cc | 25 ++++---
..._ui__controls__factory__desktop__aura__ozone.cc | 20 ------
...ktop__aura_desktop__drag__drop__client__ozone.h | 11 +++
..._widget_desktop__aura_desktop__screen__ozone.cc | 8 +--
...__aura_desktop__window__tree__host__platform.cc | 31 +++++++-
...e__host__platform__impl__interactive__uitest.cc | 11 +++
...hromium_ui_views_widget_native__widget__aura.cc | 29 --------
...src_3rdparty_chromium_ui_views_widget_widget.cc | 14 ++--
...-src_3rdparty_chromium_ui_views_widget_widget.h | 11 +++
...chromium_ui_views_window_custom__frame__view.cc | 4 +-
...c_3rdparty_chromium_ui_webui_resources_js_cr.js | 14 ----
.../files/patch-src_3rdparty_chromium_v8_BUILD.gn | 8 +--
...-src_3rdparty_chromium_v8_include_v8-internal.h | 11 +++
.../patch-src_3rdparty_chromium_v8_src_api_api.cc | 10 +--
...h-src_3rdparty_chromium_v8_src_base_atomicops.h | 13 +---
...3rdparty_chromium_v8_src_base_platform_memory.h | 16 +++++
...chromium_v8_src_base_platform_platform-posix.cc | 21 ++++--
...rc_3rdparty_chromium_v8_src_base_small-vector.h | 11 +++
...piler_backend_ia32_instruction-selector-ia32.cc | 6 +-
...rdparty_chromium_v8_src_diagnostics_perf-jit.cc | 4 +-
...3rdparty_chromium_v8_src_diagnostics_perf-jit.h | 4 +-
...src_3rdparty_chromium_v8_src_sandbox_sandbox.cc | 11 +++
...src_wasm_baseline_ia32_liftoff-assembler-ia32.h | 38 +++++-----
.../files/patch-src_core_CMakeLists.txt | 19 ++---
www/qt6-webengine/pkg-plist | 11 ++-
435 files changed, 3307 insertions(+), 2463 deletions(-)
diff --git a/www/qt6-webengine/Makefile b/www/qt6-webengine/Makefile
index 2e4d8f546493..3a63b5385b55 100644
--- a/www/qt6-webengine/Makefile
+++ b/www/qt6-webengine/Makefile
@@ -15,7 +15,7 @@
PORTNAME= webengine
DISTVERSION= ${QT6_VERSION}
-PORTREVISION= 6
+PORTREVISION= 0
CATEGORIES= www
PKGNAMEPREFIX= qt6-
@@ -27,6 +27,7 @@ BUILD_DEPENDS= ${LOCALBASE}/include/linux/videodev2.h:multimedia/v4l_compat \
${LOCALBASE}/include/vulkan/vulkan.h:graphics/vulkan-headers
LIB_DEPENDS= libavcodec.so:multimedia/ffmpeg \
libdbus-1.so:devel/dbus \
+ libdrm.so:graphics/libdrm \
libevent.so:devel/libevent \
libexpat.so:textproc/expat2 \
libfontconfig.so:x11-fonts/fontconfig \
@@ -78,15 +79,8 @@ DO_MAKE_BUILD= ${SETENV} ${MAKE_ENV} ${MAKE_CMD} ${MAKE_FLAGS} ${MAKEFILE} -j1 $
BINARY_ALIAS= python=${PYTHON_CMD}
-# Add extra-patch-no-mempcpy-nasm only when there's no mempcpy() in base.
-# Nested variable expansion avoids executing the test when not needed for
-# expanding EXTRA_PATCHES.
-# mempcpy was introduced in ee37f64cf875255338f917a9da76c643cf59786c
-EXTRA_PATCHES+= ${"${:!${GREP} mempcpy ${CROSS_SYSROOT}/usr/include/string.h \
- || ${TRUE}!}" == "":?${PATCHDIR}/extra-patch-no-mempcpy-nasm:}
-
DISTINFO_FILE= ${.CURDIR}/distinfo
-QT6_VERSION= 6.4.2
+QT6_VERSION= 6.5.0
OPTIONS_DEFAULT= ALSA
OPTIONS_SINGLE= AUDIO
diff --git a/www/qt6-webengine/distinfo b/www/qt6-webengine/distinfo
index f6a54f0fbaf2..db078bcd5dba 100644
--- a/www/qt6-webengine/distinfo
+++ b/www/qt6-webengine/distinfo
@@ -1,3 +1,3 @@
-TIMESTAMP = 1673107224
-SHA256 (KDE/Qt/6.4.2/qtwebengine-everywhere-src-6.4.2.tar.xz) = ffa945518d1cc8d9ee73523e8d9c2090844f5a2d9c7eac05c4ad079472a119c9
-SIZE (KDE/Qt/6.4.2/qtwebengine-everywhere-src-6.4.2.tar.xz) = 440538956
+TIMESTAMP = 1681646888
+SHA256 (KDE/Qt/6.5.0/qtwebengine-everywhere-src-6.5.0.tar.xz) = 2a10da34a71b307e9ff11ec086455dd20b83d5b0ee6bda499c4ba9221e306f07
+SIZE (KDE/Qt/6.5.0/qtwebengine-everywhere-src-6.5.0.tar.xz) = 411792556
diff --git a/www/qt6-webengine/files/patch-src_3rdparty_chromium_BUILD.gn b/www/qt6-webengine/files/patch-src_3rdparty_chromium_BUILD.gn
index 2a0bae22b541..99ae7981be8a 100644
--- a/www/qt6-webengine/files/patch-src_3rdparty_chromium_BUILD.gn
+++ b/www/qt6-webengine/files/patch-src_3rdparty_chromium_BUILD.gn
@@ -1,6 +1,6 @@
---- src/3rdparty/chromium/BUILD.gn.orig 2022-11-08 21:18:48 UTC
+--- src/3rdparty/chromium/BUILD.gn.orig 2023-03-28 19:45:02 UTC
+++ src/3rdparty/chromium/BUILD.gn
-@@ -55,7 +55,7 @@ declare_args() {
+@@ -60,7 +60,7 @@ declare_args() {
qtwebengine_target = "//tools/gn"
}
@@ -9,7 +9,7 @@
# An official (maximally optimized!) component (optimized for build times)
# build doesn't make sense and usually doesn't work.
assert(!is_component_build)
-@@ -451,7 +451,7 @@ group("gn_all") {
+@@ -435,7 +435,7 @@ if (!is_qtwebengine){
]
}
@@ -18,8 +18,8 @@
deps += [
"//third_party/breakpad:breakpad_unittests",
"//third_party/breakpad:core-2-minidump",
-@@ -696,7 +696,7 @@ group("gn_all") {
- host_os == "win" && !use_qt) {
+@@ -697,7 +697,7 @@ if (!is_qtwebengine){
+ host_os == "win" && !is_qtwebengine) {
deps += [ "//chrome/test/mini_installer:mini_installer_tests" ]
}
- } else if (!is_android && !is_ios && !is_fuchsia && !is_win) {
@@ -27,7 +27,16 @@
deps += [ "//third_party/breakpad:symupload($host_toolchain)" ]
}
-@@ -1172,7 +1172,7 @@ if (!is_ios && !use_qt) {
+@@ -1124,7 +1124,7 @@ if (!is_ios && !is_qtwebengine) {
+ ]
+ }
+
+- if (!is_chromeos_ash && !is_ios && !is_fuchsia && !is_android && !is_castos) {
++ if (!is_chromeos_ash && !is_ios && !is_fuchsia && !is_android && !is_castos && !is_bsd) {
+ # WPT Webdriver tests runner
+ # chrome/test/chromedriver/test/run_webdriver_tests.py
+ script_test("webdriver_wpt_tests") {
+@@ -1219,7 +1219,7 @@ if (!is_ios && !is_qtwebengine) {
data_deps += [ "//content/web_test:web_test_common_mojom_js_data_deps" ]
}
@@ -36,7 +45,7 @@
data_deps +=
[ "//third_party/breakpad:minidump_stackwalk($host_toolchain)" ]
}
-@@ -1181,7 +1181,7 @@ if (!is_ios && !use_qt) {
+@@ -1228,7 +1228,7 @@ if (!is_ios && !is_qtwebengine) {
data_deps += [ "//third_party/breakpad:dump_syms($host_toolchain)" ]
}
@@ -45,12 +54,12 @@
data_deps += [ "//third_party/breakpad:dump_syms($host_toolchain)" ]
}
-@@ -1580,7 +1580,7 @@ group("chromium_builder_perf") {
+@@ -1672,7 +1672,7 @@ group("chromium_builder_perf") {
+ data_deps += [ "//chrome/test:performance_browser_tests" ]
+ }
- if (is_win) {
- data_deps += [ "//chrome/installer/mini_installer:mini_installer" ]
-- } else {
-+ } else if (!is_bsd) {
+- if (!is_win) {
++ if (!is_win && !is_bsd) {
data_deps +=
[ "//third_party/breakpad:minidump_stackwalk($host_toolchain)" ]
}
diff --git a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_BUILD.gn b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_BUILD.gn
index 562495d3c1b5..e40cdedb3b6d 100644
--- a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_BUILD.gn
+++ b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_BUILD.gn
@@ -1,28 +1,39 @@
---- src/3rdparty/chromium/base/BUILD.gn.orig 2022-11-08 21:18:48 UTC
+--- src/3rdparty/chromium/base/BUILD.gn.orig 2023-03-28 19:45:02 UTC
+++ src/3rdparty/chromium/base/BUILD.gn
-@@ -1000,7 +1000,7 @@ jumbo_component("base") {
+@@ -164,7 +164,7 @@ buildflag_header("ios_cronet_buildflags") {
+ flags = [ "CRONET_BUILD=$is_cronet_build" ]
+ }
+
+-enable_message_pump_epoll = is_linux || is_chromeos || is_android
++enable_message_pump_epoll = (is_linux || is_chromeos || is_android) && !is_bsd
+ buildflag_header("message_pump_buildflags") {
+ header = "message_pump_buildflags.h"
+ header_dir = "base/message_loop"
+@@ -1050,7 +1050,7 @@ jumbo_component("base") {
"timer/hi_res_timer_manager_posix.cc",
]
- if (!is_nacl && !is_apple) {
+ if (!is_nacl && !is_apple && !is_bsd) {
sources += [
- "cpu_affinity_posix.cc",
- "cpu_affinity_posix.h",
-@@ -1011,6 +1011,12 @@ jumbo_component("base") {
+ "profiler/stack_base_address_posix.cc",
+ "profiler/stack_base_address_posix.h",
+@@ -1061,6 +1061,14 @@ jumbo_component("base") {
"profiler/thread_delegate_posix.h",
]
}
+
+ if (is_bsd) {
+ sources += [
++ "profiler/stack_base_address_posix.cc",
++ "profiler/stack_base_address_posix.h",
+ "profiler/stack_sampler_posix.cc",
+ ]
+ }
}
jumbo_excluded_sources = [
-@@ -1360,7 +1366,6 @@ jumbo_component("base") {
+@@ -1428,7 +1436,6 @@ jumbo_component("base") {
"process/process_metrics_linux.cc",
"threading/platform_thread_linux.cc",
]
@@ -30,44 +41,25 @@
}
if (is_linux || is_chromeos || is_android || is_fuchsia) {
-@@ -1502,6 +1507,18 @@ jumbo_component("base") {
- libs += [ "atomic" ]
- }
-
-+ # *BSD needs libkvm
-+ if (is_bsd) {
-+ libs += [ "kvm" ]
-+ }
-+
-+ if (is_freebsd) {
-+ libs += [
-+ "execinfo",
-+ "util",
-+ ]
-+ }
-+
- if (use_allocator_shim) {
- sources += [
- "allocator/allocator_shim.cc",
-@@ -1529,7 +1546,7 @@ jumbo_component("base") {
+@@ -1604,7 +1611,7 @@ jumbo_component("base") {
]
configs += [ "//base/allocator:mac_no_default_new_delete_symbols" ]
}
- if (is_chromeos || is_linux) {
+ if (is_chromeos || (is_linux && !is_bsd)) {
sources += [
- "allocator/allocator_shim_override_cpp_symbols.h",
- "allocator/allocator_shim_override_glibc_weak_symbols.h",
-@@ -1585,7 +1602,7 @@ jumbo_component("base") {
+ "allocator/partition_allocator/shim/allocator_shim_override_cpp_symbols.h",
+ "allocator/partition_allocator/shim/allocator_shim_override_glibc_weak_symbols.h",
+@@ -1658,7 +1665,7 @@ jumbo_component("base") {
# Allow more direct string conversions on platforms with native utf8
# strings
-- if (is_apple || is_chromeos || is_chromecast || is_fuchsia) {
-+ if (is_apple || is_chromeos || is_chromecast || is_fuchsia || is_bsd) {
+- if (is_apple || is_chromeos || is_castos || is_cast_android || is_fuchsia) {
++ if (is_apple || is_chromeos || is_castos || is_cast_android || is_fuchsia || is_bsd) {
defines += [ "SYSTEM_NATIVE_UTF8" ]
}
-@@ -2163,6 +2180,42 @@ jumbo_component("base") {
+@@ -2236,6 +2243,42 @@ jumbo_component("base") {
}
}
@@ -110,7 +102,16 @@
# iOS
if (is_ios) {
sources -= [
-@@ -3452,7 +3505,7 @@ test("base_unittests") {
+@@ -2333,7 +2376,7 @@ jumbo_component("base") {
+ }
+
+ if (dep_libevent) {
+- deps += [ "//third_party/libevent" ]
++ public_deps += [ "//third_party/libevent" ]
+ }
+
+ if (use_libevent) {
+@@ -3601,7 +3644,7 @@ test("base_unittests") {
}
}
@@ -119,25 +120,25 @@
sources += [
"debug/proc_maps_linux_unittest.cc",
"files/scoped_file_linux_unittest.cc",
-@@ -3500,7 +3553,7 @@ test("base_unittests") {
+@@ -3647,7 +3690,7 @@ test("base_unittests") {
+ "posix/file_descriptor_shuffle_unittest.cc",
"posix/unix_domain_socket_unittest.cc",
- "task/thread_pool/task_tracker_posix_unittest.cc",
]
- if (!is_nacl && !is_apple) {
+ if (!is_nacl && !is_apple && !is_bsd) {
sources += [
- "cpu_affinity_posix_unittest.cc",
+ "profiler/stack_base_address_posix_unittest.cc",
"profiler/stack_copier_signal_unittest.cc",
-@@ -3511,7 +3564,7 @@ test("base_unittests") {
+@@ -3658,7 +3701,7 @@ test("base_unittests") {
# Allow more direct string conversions on platforms with native utf8
# strings
-- if (is_apple || is_chromeos || is_chromecast || is_fuchsia) {
-+ if (is_apple || is_chromeos || is_chromecast || is_fuchsia || is_bsd) {
+- if (is_apple || is_chromeos || is_castos || is_cast_android || is_fuchsia) {
++ if (is_apple || is_chromeos || is_castos || is_cast_android || is_fuchsia || is_bsd) {
defines += [ "SYSTEM_NATIVE_UTF8" ]
}
-@@ -3673,7 +3726,7 @@ test("base_unittests") {
+@@ -3850,7 +3893,7 @@ test("base_unittests") {
}
}
diff --git a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_address__space__randomization.h b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_address__space__randomization.h
index 600707fc9f11..59531486585e 100644
--- a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_address__space__randomization.h
+++ b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_address__space__randomization.h
@@ -1,4 +1,4 @@
---- src/3rdparty/chromium/base/allocator/partition_allocator/address_space_randomization.h.orig 2022-09-26 10:05:50 UTC
+--- src/3rdparty/chromium/base/allocator/partition_allocator/address_space_randomization.h.orig 2023-03-28 19:45:02 UTC
+++ src/3rdparty/chromium/base/allocator/partition_allocator/address_space_randomization.h
@@ -38,7 +38,7 @@ AslrMask(uintptr_t bits) {
@@ -9,7 +9,7 @@
// We shouldn't allocate system pages at all for sanitizer builds. However,
// we do, and if random hint addresses interfere with address ranges
-@@ -121,7 +121,7 @@ AslrMask(uintptr_t bits) {
+@@ -128,7 +128,7 @@ AslrMask(uintptr_t bits) {
return AslrAddress(0x20000000ULL);
}
diff --git a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_page__allocator.h b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_page__allocator.h
index d478228c4770..07c269860248 100644
--- a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_page__allocator.h
+++ b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_page__allocator.h
@@ -1,9 +1,9 @@
---- src/3rdparty/chromium/base/allocator/partition_allocator/page_allocator.h.orig 2022-09-26 10:05:50 UTC
+--- src/3rdparty/chromium/base/allocator/partition_allocator/page_allocator.h.orig 2023-03-28 19:45:02 UTC
+++ src/3rdparty/chromium/base/allocator/partition_allocator/page_allocator.h
-@@ -194,7 +194,7 @@ constexpr BASE_EXPORT bool DecommittedMemoryIsAlwaysZe
- // Whether decommitted memory is guaranteed to be zeroed when it is
+@@ -231,7 +231,7 @@ constexpr PA_COMPONENT_EXPORT(
// recommitted. Do not assume that this will not change over time.
- constexpr BASE_EXPORT bool DecommittedMemoryIsAlwaysZeroed() {
+ constexpr PA_COMPONENT_EXPORT(
+ PARTITION_ALLOC) bool DecommittedMemoryIsAlwaysZeroed() {
-#if BUILDFLAG(IS_APPLE)
+#if BUILDFLAG(IS_APPLE) || BUILDFLAG(IS_BSD)
return false;
diff --git a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_page__allocator__constants.h b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_page__allocator__constants.h
index 126aa403ea69..24bb1167dd4f 100644
--- a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_page__allocator__constants.h
+++ b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_page__allocator__constants.h
@@ -1,6 +1,6 @@
---- src/3rdparty/chromium/base/allocator/partition_allocator/page_allocator_constants.h.orig 2022-09-26 10:05:50 UTC
+--- src/3rdparty/chromium/base/allocator/partition_allocator/page_allocator_constants.h.orig 2023-03-28 19:45:02 UTC
+++ src/3rdparty/chromium/base/allocator/partition_allocator/page_allocator_constants.h
-@@ -24,7 +24,7 @@
+@@ -25,7 +25,7 @@
// elimination.
#define PAGE_ALLOCATOR_CONSTANTS_DECLARE_CONSTEXPR __attribute__((const))
@@ -9,16 +9,16 @@
// This should work for all POSIX (if needed), but currently all other
// supported OS/architecture combinations use either hard-coded values
// (such as x86) or have means to determine these values without needing
-@@ -79,7 +79,7 @@ PageAllocationGranularityShift() {
+@@ -81,7 +81,7 @@ PageAllocationGranularityShift() {
return 14; // 16kB
#elif BUILDFLAG(IS_APPLE) && defined(ARCH_CPU_64_BITS)
- return vm_page_shift;
+ return static_cast<size_t>(vm_page_shift);
-#elif BUILDFLAG(IS_LINUX) && defined(ARCH_CPU_ARM64)
+#elif (BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_BSD)) && defined(ARCH_CPU_ARM64)
// arm64 supports 4kb (shift = 12), 16kb (shift = 14), and 64kb (shift = 16)
// page sizes. Retrieve from or initialize cache.
- int shift = page_characteristics.shift.load(std::memory_order_relaxed);
-@@ -99,7 +99,7 @@ PageAllocationGranularity() {
+ size_t shift = page_characteristics.shift.load(std::memory_order_relaxed);
+@@ -102,7 +102,7 @@ PageAllocationGranularity() {
// This is literally equivalent to |1 << PageAllocationGranularityShift()|
// below, but was separated out for IS_APPLE to avoid << on a non-constexpr.
return vm_page_size;
@@ -26,4 +26,13 @@
+#elif (BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_BSD)) && defined(ARCH_CPU_ARM64)
// arm64 supports 4kb, 16kb, and 64kb page sizes. Retrieve from or
// initialize cache.
- int size = page_characteristics.size.load(std::memory_order_relaxed);
+ size_t size = page_characteristics.size.load(std::memory_order_relaxed);
+@@ -141,7 +141,7 @@ SystemPageSize() {
+ PAGE_ALLOCATOR_CONSTANTS_DECLARE_CONSTEXPR PA_ALWAYS_INLINE size_t
+ SystemPageSize() {
+ #if (BUILDFLAG(IS_APPLE) && defined(ARCH_CPU_64_BITS)) || \
+- (BUILDFLAG(IS_LINUX) && defined(ARCH_CPU_ARM64))
++ ((BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_BSD)) && defined(ARCH_CPU_ARM64))
+ // This is literally equivalent to |1 << SystemPageShift()| below, but was
+ // separated out for 64-bit IS_APPLE and arm64 on Linux to avoid << on a
+ // non-constexpr.
diff --git a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_page__allocator__internals__posix.h b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_page__allocator__internals__posix.h
index 9af9d257cf60..c5f4c4fd503e 100644
--- a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_page__allocator__internals__posix.h
+++ b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_page__allocator__internals__posix.h
@@ -1,6 +1,6 @@
---- src/3rdparty/chromium/base/allocator/partition_allocator/page_allocator_internals_posix.h.orig 2022-09-26 10:05:50 UTC
+--- src/3rdparty/chromium/base/allocator/partition_allocator/page_allocator_internals_posix.h.orig 2023-03-28 19:45:02 UTC
+++ src/3rdparty/chromium/base/allocator/partition_allocator/page_allocator_internals_posix.h
-@@ -352,8 +352,12 @@ void DiscardSystemPagesInternal(uintptr_t address, siz
+@@ -356,8 +356,12 @@ void DiscardSystemPagesInternal(uintptr_t address, siz
void DiscardSystemPagesInternal(uintptr_t address, size_t length) {
void* ptr = reinterpret_cast<void*>(address);
diff --git a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__address__space.cc b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__address__space.cc
index d5eb2f8e6ab8..00e9ceb91e9f 100644
--- a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__address__space.cc
+++ b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__address__space.cc
@@ -1,7 +1,7 @@
---- src/3rdparty/chromium/base/allocator/partition_allocator/partition_address_space.cc.orig 2022-09-26 10:05:50 UTC
+--- src/3rdparty/chromium/base/allocator/partition_allocator/partition_address_space.cc.orig 2023-03-28 19:45:02 UTC
+++ src/3rdparty/chromium/base/allocator/partition_allocator/partition_address_space.cc
-@@ -184,7 +184,7 @@ void PartitionAddressSpace::UninitConfigurablePoolForT
- setup_.configurable_pool_ = 0;
+@@ -294,7 +294,7 @@ void PartitionAddressSpace::UninitConfigurablePoolForT
+ setup_.configurable_pool_base_mask_ = 0;
}
-#if BUILDFLAG(IS_LINUX) && defined(ARCH_CPU_ARM64)
diff --git a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc.cc b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc.cc
deleted file mode 100644
index bcd2666febd2..000000000000
--- a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc.cc
+++ /dev/null
@@ -1,17 +0,0 @@
---- src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc.cc.orig 2022-11-06 10:07:10 UTC
-+++ src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc.cc
-@@ -63,8 +63,14 @@ void PartitionAllocGlobalInit(OomFunction on_out_of_me
- "maximum direct mapped allocation");
-
- // Check that some of our zanier calculations worked out as expected.
-+#if defined(__i386__) && defined(OS_FREEBSD)
-+ // alignof(std::max_align_t) is only 4 on FreeBSD/i386
-+ static_assert(internal::kSmallestBucket >= internal::kAlignment,
-+ "generic smallest bucket");
-+#else
- static_assert(internal::kSmallestBucket == internal::kAlignment,
- "generic smallest bucket");
-+#endif
- static_assert(internal::kMaxBucketed == 917504, "generic max bucketed");
- STATIC_ASSERT_OR_PA_CHECK(
- internal::MaxSystemPagesPerRegularSlotSpan() <= 16,
diff --git a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__base_rand__util__posix.cc b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__base_rand__util__posix.cc
new file mode 100644
index 000000000000..a76771eec9d5
--- /dev/null
+++ b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__base_rand__util__posix.cc
@@ -0,0 +1,13 @@
+--- src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc_base/rand_util_posix.cc.orig 2023-03-28 19:45:02 UTC
++++ src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc_base/rand_util_posix.cc
+@@ -86,6 +86,10 @@ void RandBytes(void* output, size_t output_length) {
+ if (getentropy(output, output_length) == 0) {
+ return;
+ }
++#elif BUILDFLAG(IS_BSD)
++ if (getentropy(output, output_length) == 0) {
++ return;
++ }
+ #endif
+
+ // If the OS-specific mechanisms didn't work, fall through to reading from
diff --git a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__base_threading_platform__thread__internal__posix.h b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__base_threading_platform__thread__internal__posix.h
new file mode 100644
index 000000000000..d0992005bcf3
--- /dev/null
+++ b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__base_threading_platform__thread__internal__posix.h
@@ -0,0 +1,11 @@
+--- src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc_base/threading/platform_thread_internal_posix.h.orig 2023-03-28 19:45:02 UTC
++++ src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc_base/threading/platform_thread_internal_posix.h
+@@ -10,7 +10,7 @@ namespace partition_alloc::internal::base::internal {
+
+ namespace partition_alloc::internal::base::internal {
+
+-#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)
++#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_BSD)
+ // Current thread id is cached in thread local storage for performance reasons.
+ // In some rare cases it's important to invalidate that cache explicitly (e.g.
+ // after going through clone() syscall which does not call pthread_atfork()
diff --git a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__base_threading_platform__thread__posix.cc b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__base_threading_platform__thread__posix.cc
new file mode 100644
index 000000000000..06ebd5c93efe
--- /dev/null
+++ b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__base_threading_platform__thread__posix.cc
@@ -0,0 +1,11 @@
+--- src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc_base/threading/platform_thread_posix.cc.orig 2023-03-28 19:45:02 UTC
++++ src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc_base/threading/platform_thread_posix.cc
+@@ -17,7 +17,7 @@
+ #include "base/allocator/partition_allocator/partition_alloc_base/threading/platform_thread_internal_posix.h"
+ #include "build/build_config.h"
+
+-#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)
++#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_BSD)
+ #include <sys/syscall.h>
+ #include <atomic>
+ #endif
diff --git a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__config.h b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__config.h
index bf2ddbcbaf2b..6a529fb2e456 100644
--- a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__config.h
+++ b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__config.h
@@ -1,6 +1,6 @@
---- src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc_config.h.orig 2022-11-06 10:11:11 UTC
+--- src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc_config.h.orig 2023-03-28 19:45:02 UTC
+++ src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc_config.h
-@@ -66,7 +66,7 @@ static_assert(sizeof(void*) != 8, "");
+@@ -76,7 +76,7 @@ static_assert(sizeof(void*) != 8, "");
// POSIX is not only UNIX, e.g. macOS and other OSes. We do use Linux-specific
// features such as futex(2).
@@ -9,7 +9,7 @@
#define PA_HAS_LINUX_KERNEL
#endif
-@@ -186,7 +186,7 @@ constexpr bool kUseLazyCommit = false;
+@@ -197,7 +197,7 @@ constexpr bool kUseLazyCommit = false;
// On these platforms, lock all the partitions before fork(), and unlock after.
// This may be required on more platforms in the future.
@@ -18,12 +18,12 @@
#define PA_HAS_ATFORK_HANDLER
#endif
-@@ -225,7 +225,7 @@ constexpr bool kUseLazyCommit = false;
+@@ -238,7 +238,7 @@ constexpr bool kUseLazyCommit = false;
//
// Also enabled on ARM64 macOS, as the 16kiB pages on this platform lead to
// larger slot spans.
-#if BUILDFLAG(IS_LINUX) || (BUILDFLAG(IS_MAC) && defined(ARCH_CPU_ARM64))
+#if BUILDFLAG(IS_LINUX) || (BUILDFLAG(IS_MAC) && defined(ARCH_CPU_ARM64)) || BUILDFLAG(IS_BSD)
#define PA_PREFER_SMALLER_SLOT_SPANS
- #endif // BUILDFLAG(IS_LINUX)
+ #endif // BUILDFLAG(IS_LINUX) || (BUILDFLAG(IS_MAC) && defined(ARCH_CPU_ARM64))
diff --git a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__constants.h b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__constants.h
index ca9926dc66b4..a77622469f07 100644
--- a/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__constants.h
+++ b/www/qt6-webengine/files/patch-src_3rdparty_chromium_base_allocator_partition__allocator_partition__alloc__constants.h
@@ -1,11 +1,20 @@
---- src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc_constants.h.orig 2022-09-26 10:05:50 UTC
+--- src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc_constants.h.orig 2023-03-28 19:45:02 UTC
+++ src/3rdparty/chromium/base/allocator/partition_allocator/partition_alloc_constants.h
-@@ -80,7 +80,7 @@ PartitionPageShift() {
+@@ -91,7 +91,7 @@ PartitionPageShift() {
return 18; // 256 KiB
}
#elif (BUILDFLAG(IS_APPLE) && defined(ARCH_CPU_64_BITS)) || \
- (BUILDFLAG(IS_LINUX) && defined(ARCH_CPU_ARM64))
+ ((BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_BSD)) && defined(ARCH_CPU_ARM64))
- PAGE_ALLOCATOR_CONSTANTS_DECLARE_CONSTEXPR ALWAYS_INLINE size_t
*** 11660 LINES SKIPPED ***